from distutils.core import setup

setup(
    name='Elpotrero',
    version='1.1',
    packages=['elpotrero', 'elpotrero.lib',],
    license='Creative Commons Attribution-Noncommercial-Share Alike license',
    long_description=open('README.txt').read(),
)
